@@ -47,7 +47,7 @@ DesktopWidget::DesktopWidget(QWidget *parent, QString appletId, bool debug) :
     XChangeProperty(QX11Info::display(), winId(), winTypeAtom, XA_ATOM, 32,
             PropModeReplace, (unsigned char *) &homeAppletAtom, 1);
 
-    setAttribute(Qt::WA_Maemo5NonComposited, true);
+    //setAttribute(Qt::WA_Maemo5NonComposited, true);
 
     if (!appletId.isEmpty())
         m_AppletId = appletId;
